@@ -5,6 +5,7 @@
 #include <utility>
 
 #include "cmGeneratorExpression.h"
+#include "cmListFileCache.h"
 #include "cmMakefile.h"
 #include "cmMessageType.h"
 #include "cmStringAlgorithms.h"
@@ -48,7 +49,8 @@ private:
   {
     std::string const& base = this->Makefile->GetCurrentSourceDirectory();
     tgt->AppendProperty("PRECOMPILE_HEADERS",
-                        this->Join(ConvertToAbsoluteContent(content, base)));
+                        this->Join(ConvertToAbsoluteContent(content, base)),
+                        this->Makefile->GetBacktrace());
     return true;
   }
 
